<div align="center">
  <a href="https://v2.nonebot.dev/store"><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/nbp_logo.png" width="180" height="180" alt="NoneBotPluginLogo"></a>
  <br>
  <p><img src="https://github.com/A-kirami/nonebot-plugin-template/blob/resources/NoneBotPlugin.svg" width="240" alt="NoneBotPluginText"></p>
</div>

<div align="center">

# nonebot-plugin-track-anime

_✨ NoneBot 插件简单描述 ✨_

<a href="./LICENSE">
    <img src="https://img.shields.io/github/license/owner/nonebot-plugin-track-anime.svg" alt="license">
</a>
<a href="https://pypi.python.org/pypi/nonebot-plugin-track-anime">
    <img src="https://img.shields.io/pypi/v/nonebot-plugin-track-anime.svg" alt="pypi">
</a>
<img src="https://img.shields.io/badge/python-3.9+-blue.svg" alt="python">

## 📖 介绍

这是一个用于追番的工具，访问mikanani.me进行使用，力求简单易用。
本插件需要机器人所在网络环境能够访问mikanani.me


## 💿 安装

<details open>
<summary>使用 nb-cli 安装</summary>
在 nonebot2 项目的根目录下打开命令行, 输入以下指令即可安装

    nb plugin install nonebot-plugin-track-anime

</details>

<details>
<summary>使用包管理器安装</summary>
在 nonebot2 项目的插件目录下, 打开命令行, 根据你使用的包管理器, 输入相应的安装命令

<details>
<summary>pip</summary>

    pip install nonebot-plugin-track-anime
</details>
<details>
<summary>pdm</summary>

    pdm add nonebot-plugin-track-anime
</details>
<details>
<summary>poetry</summary>

    poetry add nonebot-plugin-track-anime
</details>
<details>
<summary>conda</summary>

    conda install nonebot-plugin-track-anime
</details>

打开 nonebot2 项目根目录下的 `pyproject.toml` 文件, 在 `[tool.nonebot]` 部分追加写入

    plugins = ["nonebot_plugin_track-anime"]

</details>



## 🎉 使用
![img](README.assets/fbad530a6696d9aa5f4fe85f7216b5d4_720.jpg)
